==> webknossos-0.9.3-py3-none-any.whl: webknossos/client/_generated/api/default/user_logged_time.py <==
from typing import Any, Dict, Optional

import httpx

from ...client import Client
from ...models.user_logged_time_response_200 import UserLoggedTimeResponse200
from ...types import Response


def _get_kwargs(
    id: str,
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/api/users/{id}/loggedTime".format(client.base_url, id=id)

    headers: Dict[str, Any] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[UserLoggedTimeResponse200]:
    if response.status_code == 200:
        response_200 = UserLoggedTimeResponse200.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[UserLoggedTimeResponse200]:
    return Response(
        status_code=response.status_code,
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    id: str,
    *,
    client: Client,
) -> Response[UserLoggedTimeResponse200]:
    kwargs = _get_kwargs(
        id=id,
        client=client,
    )

    response = httpx.get(
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    id: str,
    *,
    client: Client,
) -> Optional[UserLoggedTimeResponse200]:
    """ """

    return sync_detailed(
        id=id,
        client=client,
    ).parsed


async def asyncio_detailed(
    id: str,
    *,
    client: Client,
) -> Response[UserLoggedTimeResponse200]:
    kwargs = _get_kwargs(
        id=id,
        client=client,
    )

    async with httpx.AsyncClient() as _client:
        response = await _client.get(**kwargs)

    return _build_response(response=response)


async def asyncio(
    id: str,
    *,
    client: Client,
) -> Optional[UserLoggedTimeResponse200]:
    """ """

    return (
        await asyncio_detailed(
            id=id,
            client=client,
        )
    ).parsed

==> webknossos-0.12.5-py3-none-any.whl: webknossos/client/_generated/api/default/user_logged_time.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional

import httpx

from ...client import Client
from ...models.user_logged_time_response_200 import UserLoggedTimeResponse200
from ...types import Response


def _get_kwargs(
    id: str,
    *,
    client: Client,
) -> Dict[str, Any]:
    url = "{}/api/users/{id}/loggedTime".format(client.base_url, id=id)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
    }


def _parse_response(*, response: httpx.Response) -> Optional[UserLoggedTimeResponse200]:
    if response.status_code == 200:
        response_200 = UserLoggedTimeResponse200.from_dict(response.json())

        return response_200
    return None


def _build_response(*, response: httpx.Response) -> Response[UserLoggedTimeResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(response=response),
    )


def sync_detailed(
    id: str,
    *,
    client: Client,
) -> Response[UserLoggedTimeResponse200]:
    """Get the logged time of the passed user. Only available for admins or team managers of the user in
    question.

    Args:
        id (str):

    Returns:
        Response[UserLoggedTimeResponse200]
    """

    kwargs = _get_kwargs(
        id=id,
        client=client,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(response=response)


def sync(
    id: str,
    *,
    client: Client,
) -> Optional[UserLoggedTimeResponse200]:
    """Get the logged time of the passed user. Only available for admins or team managers of the user in
    question.

    Args:
        id (str):

    Returns:
        Response[UserLoggedTimeResponse200]
    """

    return sync_detailed(
        id=id,
        client=client,
    ).parsed


async def asyncio_detailed(
    id: str,
    *,
    client: Client,
) -> Response[UserLoggedTimeResponse200]:
    """Get the logged time of the passed user. Only available for admins or team managers of the user in
    question.

    Args:
        id (str):

    Returns:
        Response[UserLoggedTimeResponse200]
    """

    kwargs = _get_kwargs(
        id=id,
        client=client,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(response=response)


async def asyncio(
    id: str,
    *,
    client: Client,
) -> Optional[UserLoggedTimeResponse200]:
    """Get the logged time of the passed user. Only available for admins or team managers of the user in
    question.

    Args:
        id (str):

    Returns:
        Response[UserLoggedTimeResponse200]
    """

    return (
        await asyncio_detailed(
            id=id,
            client=client,
        )
    ).parsed
